Translation class

Represents a translation as value of a label in the language with the languageCode.

Constructors

Translation(String languageCode, String value)
Creates a new Translation with a value for a given language with languageCode.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode → String
The language code.
final
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
templatedValues → List<StringTemplate>
The templated values are portions of the value in which dynamic values can be inserted.
no setter
value → String
The translatio value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited